@@ -657,54 +657,6 @@ AccountSetPtr AccountManager::textChatroomAccounts() const
     return filterAccounts(filter);
 }
 
-/**
- * Return a set of accounts containing all accounts that support audio calls (using the
- * Call interface) by providing a contact identifier.
- *
- * For this method to work, you must use an AccountFactory which makes Account::FeatureCapabilities
- * ready.
- *
- * This method requires AccountManager::FeatureCore to be ready.
- *
- * \return A pointer to an AccountSet object containing the matching accounts.
- */
-AccountSetPtr AccountManager::audioCallAccounts() const
-{
-    if (!accountFactory()->features().contains(Account::FeatureCapabilities)) {
-        warning() << "Account filtering by capabilities can only be used with an AccountFactory"
-            << "which makes Account::FeatureCapabilities ready";
-        return filterAccounts(AccountFilterConstPtr());
-    }
-
-    AccountCapabilityFilterPtr filter = AccountCapabilityFilter::create();
-    filter->addRequestableChannelClassSubset(RequestableChannelClassSpec::audioCall());
-    return filterAccounts(filter);
-}
-
-/**
- * Return a set of accounts containing all accounts that support video calls (using the
- * Call interface) by providing a contact identifier.
- *
- * For this method to work, you must use an AccountFactory which makes Account::FeatureCapabilities
- * ready.
- *
- * This method requires AccountManager::FeatureCore to be ready.
- *
- * \return A pointer to an AccountSet object containing the matching accounts.
- */
-AccountSetPtr AccountManager::videoCallAccounts() const
-{
-    if (!accountFactory()->features().contains(Account::FeatureCapabilities)) {
-        warning() << "Account filtering by capabilities can only be used with an AccountFactory"
-            << "which makes Account::FeatureCapabilities ready";
-        return filterAccounts(AccountFilterConstPtr());
-    }
-
-    AccountCapabilityFilterPtr filter = AccountCapabilityFilter::create();
-    filter->addRequestableChannelClassSubset(RequestableChannelClassSpec::videoCall());
-    return filterAccounts(filter);
-}
-
 /**
  * Return a set of accounts containing all accounts that support media calls (using the
  * StreamedMedia interface) by providing a contact identifier.
@@ -937,9 +889,9 @@ AccountSetPtr AccountManager::filterAccounts(const QVariantMap &filter) const
  *
  * \param path The account object path.
  * \return A pointer to an AccountSet object containing the matching accounts.
- * \sa allAccounts(), accountsForObjectPaths()
+ * \sa allAccounts(), accountsForPaths()
  */
-AccountPtr AccountManager::accountForObjectPath(const QString &path) const
+AccountPtr AccountManager::accountForPath(const QString &path) const
 {
     if (!isReady(FeatureCore)) {
         return AccountPtr();
@@ -948,14 +900,6 @@ AccountPtr AccountManager::accountForObjectPath(const QString &path) const
     return mPriv->accounts.value(path);
 }
 
-/**
- * \deprecated See accountForObjectPath()
- */
-AccountPtr AccountManager::accountForPath(const QString &path) const
-{
-    return accountForObjectPath(path);
-}
-
 /**
  * Return a list of accounts for the given \a paths.
  *
@@ -968,9 +912,9 @@ AccountPtr AccountManager::accountForPath(const QString &path) const
  * \param paths List of accounts object paths.
  * \return A list of pointers to Account objects for the given
  *         \a paths. Null AccountPtr objects will be used as list elements for each invalid path.
- * \sa allAccounts(), accountForObjectPath()
+ * \sa allAccounts(), accountForPath()
  */
-QList<AccountPtr> AccountManager::accountsForObjectPaths(const QStringList &paths) const
+QList<AccountPtr> AccountManager::accountsForPaths(const QStringList &paths) const
 {
     if (!isReady(FeatureCore)) {
         return QList<AccountPtr>();
@@ -978,19 +922,11 @@ QList<AccountPtr> AccountManager::accountsForObjectPaths(const QStringList &path
 
     QList<AccountPtr> result;
     foreach (const QString &path, paths) {
-        result << accountForObjectPath(path);
+        result << accountForPath(path);
     }
     return result;
 }
 
-/**
- * \deprecated See accountsForObjectPaths()
- */
-QList<AccountPtr> AccountManager::accountsForPaths(const QStringList &paths) const
-{
-    return accountsForObjectPaths(paths);
-}
-
 /**
  * Return a list of the fully qualified names of properties that can be set
  * when calling createAccount().
