@@ -28,6 +28,7 @@
 
 #include "TelepathyQt/debug-internal.h"
 
+#include <TelepathyQt/CallChannel>
 #include <TelepathyQt/Channel>
 #include <TelepathyQt/ChannelClassSpec>
 #include <TelepathyQt/ChannelClassFeatures>
@@ -40,6 +41,7 @@
 #include <TelepathyQt/OutgoingFileTransferChannel>
 #include <TelepathyQt/OutgoingStreamTubeChannel>
 #include <TelepathyQt/RoomListChannel>
+#include <TelepathyQt/ServerAuthenticationChannel>
 #include <TelepathyQt/StreamTubeChannel>
 #include <TelepathyQt/StreamedMediaChannel>
 #include <TelepathyQt/TextChannel>
@@ -97,6 +99,7 @@ ChannelFactory::ChannelFactory(const QDBusConnection &bus)
 {
     setSubclassForTextChats<TextChannel>();
     setSubclassForTextChatrooms<TextChannel>();
+    setSubclassForCalls<CallChannel>();
     setSubclassForStreamedMediaCalls<StreamedMediaChannel>();
     setSubclassForRoomLists<RoomListChannel>();
     setSubclassForIncomingFileTransfers<IncomingFileTransferChannel>();
@@ -106,6 +109,7 @@ ChannelFactory::ChannelFactory(const QDBusConnection &bus)
     setSubclassForIncomingRoomStreamTubes<IncomingStreamTubeChannel>();
     setSubclassForOutgoingRoomStreamTubes<OutgoingStreamTubeChannel>();
     setSubclassForContactSearches<ContactSearchChannel>();
+    setSubclassForServerAuthentication<ServerAuthenticationChannel>();
     setFallbackSubclass<Channel>();
 }
 
@@ -165,6 +169,25 @@ void ChannelFactory::setConstructorForTextChatrooms(const ConstructorConstPtr &c
     setConstructorFor(ChannelClassSpec::textChatroom(additionalProps), ctor);
 }
 
+Features ChannelFactory::featuresForCalls(const QVariantMap &additionalProps) const
+{
+    return featuresFor(ChannelClassSpec::audioCall(additionalProps));
+}
+
+void ChannelFactory::addFeaturesForCalls(const Features &features,
+        const QVariantMap &additionalProps)
+{
+    addFeaturesFor(ChannelClassSpec::audioCall(additionalProps), features);
+    addFeaturesFor(ChannelClassSpec::videoCall(additionalProps), features);
+}
+
+void ChannelFactory::setConstructorForCalls(const ConstructorConstPtr &ctor,
+        const QVariantMap &additionalProps)
+{
+    setConstructorFor(ChannelClassSpec::audioCall(additionalProps), ctor);
+    setConstructorFor(ChannelClassSpec::videoCall(additionalProps), ctor);
+}
+
 Features ChannelFactory::featuresForStreamedMediaCalls(const QVariantMap &additionalProps) const
 {
     return featuresFor(ChannelClassSpec::streamedMediaCall(additionalProps));
@@ -380,6 +403,29 @@ void ChannelFactory::setConstructorForContactSearches(const ConstructorConstPtr
     setConstructorFor(ChannelClassSpec::contactSearch(additionalProps), ctor);
 }
 
+Features ChannelFactory::featuresForServerAuthentication(const QVariantMap &additionalProps) const
+{
+    return featuresFor(ChannelClassSpec::serverAuthentication(additionalProps));
+}
+
+void ChannelFactory::addFeaturesForServerAuthentication(const Features &features,
+        const QVariantMap &additionalProps)
+{
+    addFeaturesFor(ChannelClassSpec::serverAuthentication(additionalProps), features);
+}
+
+ChannelFactory::ConstructorConstPtr ChannelFactory::constructorForServerAuthentication(
+        const QVariantMap &additionalProps) const
+{
+    return constructorFor(ChannelClassSpec::serverAuthentication(additionalProps));
+}
+
+void ChannelFactory::setConstructorForServerAuthentication(const ConstructorConstPtr &ctor,
+        const QVariantMap &additionalProps)
+{
+    setConstructorFor(ChannelClassSpec::serverAuthentication(additionalProps), ctor);
+}
+
 Features ChannelFactory::commonFeatures() const
 {
     return featuresFor(ChannelClassSpec());
