@@ -129,17 +129,11 @@ QueuedContactFactory::~QueuedContactFactory()
 
 void QueuedContactFactory::processNextRequest()
 {
-    if (m_isProcessing) {
+    if (m_isProcessing || m_queue.isEmpty()) {
         // Return, nothing to do
         return;
     }
 
-    if (m_queue.isEmpty()) {
-        // Queue completed, notify and return
-        emit queueCompleted();
-        return;
-    }
-
     m_isProcessing = true;
 
     Entry entry = m_queue.dequeue();
@@ -160,8 +154,8 @@ QUuid QueuedContactFactory::appendNewRequest(const Tp::UIntList &handles)
     entry.handles = handles;
     m_queue.enqueue(entry);
 
-    // Enqueue a process request in the event loop
-    QTimer::singleShot(0, this, SLOT(processNextRequest()));
+    // Check if we can process a request
+    processNextRequest();
 
     // Return the UUID
     return entry.uuid;
