@@ -5,17 +5,17 @@
 
 #include <QtTest/QtTest>
 
-#define TP_QT4_ENABLE_LOWLEVEL_API
+#define TP_QT_ENABLE_LOWLEVEL_API
 
-#include <TelepathyQt4/ChannelFactory>
-#include <TelepathyQt4/Connection>
-#include <TelepathyQt4/ConnectionLowlevel>
-#include <TelepathyQt4/Contact>
-#include <TelepathyQt4/ContactFactory>
-#include <TelepathyQt4/ContactManager>
-#include <TelepathyQt4/PendingContacts>
-#include <TelepathyQt4/PendingReady>
-#include <TelepathyQt4/Debug>
+#include <TelepathyQt/ChannelFactory>
+#include <TelepathyQt/Connection>
+#include <TelepathyQt/ConnectionLowlevel>
+#include <TelepathyQt/Contact>
+#include <TelepathyQt/ContactFactory>
+#include <TelepathyQt/ContactManager>
+#include <TelepathyQt/PendingContacts>
+#include <TelepathyQt/PendingReady>
+#include <TelepathyQt/Debug>
 
 #include <telepathy-glib/debug.h>
 
@@ -535,7 +535,7 @@ void TestConnRosterGroupsLegacy::testNotADeathTrap()
     QCOMPARE(mLoop->exec(), 0);
     QVERIFY(mContact->id() == QLatin1String("friendorfoe@example.com"));
 
-    // Roster operations SHOULD still fail though, as FeatureRoster isn't ready 
+    // Roster operations SHOULD still fail though, as FeatureRoster isn't ready
     QVERIFY(connect(mConn->contactManager()->requestPresenceSubscription(
                     QList<ContactPtr>() << mContact,
                     QLatin1String("I just want to see you fail")),
@@ -564,7 +564,7 @@ void TestConnRosterGroupsLegacy::testNotADeathTrap()
                 SLOT(expectFailure(Tp::PendingOperation*))));
     QCOMPARE(mLoop->exec(), 0);
 
-    QVERIFY(connect(mConn->contactManager()->blockContacts(QList<ContactPtr>() << mContact, true),
+    QVERIFY(connect(mConn->contactManager()->blockContacts(QList<ContactPtr>() << mContact),
                 SIGNAL(finished(Tp::PendingOperation*)),
                 SLOT(expectFailure(Tp::PendingOperation*))));
     QCOMPARE(mLoop->exec(), 0);
@@ -784,7 +784,7 @@ void TestConnRosterGroupsLegacy::testNotADeathTrap()
                 SLOT(expectFailure(Tp::PendingOperation*))));
     QCOMPARE(mLoop->exec(), 0);
 
-    QVERIFY(connect(mConn->contactManager()->blockContacts(QList<ContactPtr>() << mContact, true),
+    QVERIFY(connect(mConn->contactManager()->blockContacts(QList<ContactPtr>() << mContact),
                 SIGNAL(finished(Tp::PendingOperation*)),
                 SLOT(expectFailure(Tp::PendingOperation*))));
     QCOMPARE(mLoop->exec(), 0);
