@@ -120,6 +120,7 @@ get_property (GObject *object,
               GParamSpec *pspec)
 {
   TpTestsTextChannelNull *self = TP_TESTS_TEXT_CHANNEL_NULL (object);
+  TpTestsTextChannelNullClass *klass = TP_TESTS_TEXT_CHANNEL_NULL_GET_CLASS (self);
 
   switch (property_id)
     {
@@ -160,7 +161,7 @@ get_property (GObject *object,
         }
       break;
     case PROP_INTERFACES:
-      g_value_set_boxed (value, tp_tests_text_channel_null_interfaces);
+      g_value_set_boxed (value, klass->interfaces);
       break;
     case PROP_CONNECTION:
       g_value_set_object (value, self->priv->conn);
@@ -254,6 +255,8 @@ tp_tests_text_channel_null_class_init (TpTestsTextChannelNullClass *klass)
 
   g_type_class_add_private (klass, sizeof (TpTestsTextChannelNullPrivate));
 
+  klass->interfaces = tp_tests_text_channel_null_interfaces;
+
   object_class->constructor = constructor;
   object_class->set_property = set_property;
   object_class->get_property = get_property;
@@ -334,7 +337,7 @@ props_finalize (GObject *object)
 
   g_hash_table_unref (self->dbus_property_interfaces_retrieved);
 
-  ((GObjectClass *) tp_tests_text_channel_null_parent_class)->finalize (object);
+  ((GObjectClass *) tp_tests_props_text_channel_parent_class)->finalize (object);
 }
 
 static void
@@ -368,6 +371,11 @@ tp_tests_props_text_channel_class_init (TpTestsPropsTextChannelClass *klass)
       G_STRUCT_OFFSET (TpTestsPropsTextChannelClass, dbus_properties_class));
 }
 
+static const char *tp_tests_props_group_text_channel_interfaces[] = {
+    TP_IFACE_CHANNEL_INTERFACE_GROUP,
+    NULL
+};
+
 static void
 tp_tests_props_group_text_channel_init (TpTestsPropsGroupTextChannel *self)
 {
@@ -394,6 +402,8 @@ static void
 group_finalize (GObject *self)
 {
   tp_group_mixin_finalize (self);
+
+  ((GObjectClass *) tp_tests_props_group_text_channel_parent_class)->finalize (self);
 }
 
 static gboolean
@@ -424,6 +434,7 @@ static void
 tp_tests_props_group_text_channel_class_init (TpTestsPropsGroupTextChannelClass *klass)
 {
   GObjectClass *object_class = (GObjectClass *) klass;
+  TpTestsTextChannelNullClass *null_class = (TpTestsTextChannelNullClass *) klass;
   static TpDBusPropertiesMixinPropImpl group_props[] = {
       { "GroupFlags", NULL, NULL },
       { "HandleOwners", NULL, NULL },
@@ -434,6 +445,8 @@ tp_tests_props_group_text_channel_class_init (TpTestsPropsGroupTextChannelClass
       { NULL }
   };
 
+  null_class->interfaces = tp_tests_props_group_text_channel_interfaces;
+
   object_class->constructed = group_constructed;
   object_class->finalize = group_finalize;
 
@@ -485,11 +498,12 @@ channel_get_interfaces (TpSvcChannel *iface,
                         DBusGMethodInvocation *context)
 {
   TpTestsTextChannelNull *self = TP_TESTS_TEXT_CHANNEL_NULL (iface);
+  TpTestsTextChannelNullClass *klass = TP_TESTS_TEXT_CHANNEL_NULL_GET_CLASS (self);
 
   self->get_interfaces_called++;
 
   tp_svc_channel_return_from_get_interfaces (context,
-      tp_tests_text_channel_null_interfaces);
+      klass->interfaces);
 }
 
 static void
@@ -527,3 +541,42 @@ text_iface_init (gpointer iface,
   IMPLEMENT (send);
 #undef IMPLEMENT
 }
+
+GHashTable *
+tp_tests_text_channel_get_props (TpTestsTextChannelNull *self)
+{
+  GHashTable *props;
+  TpHandleType handle_type;
+  TpHandle handle;
+  gchar *target_id;
+  gboolean requested;
+  TpHandle initiator_handle;
+  gchar *initiator_id;
+  GStrv interfaces;
+
+  g_object_get (self,
+      "handle-type", &handle_type,
+      "handle", &handle,
+      "target-id", &target_id,
+      "requested", &requested,
+      "initiator-handle", &initiator_handle,
+      "initiator-id", &initiator_id,
+      "interfaces", &interfaces,
+      NULL);
+
+  props = tp_asv_new (
+      TP_PROP_CHANNEL_CHANNEL_TYPE, G_TYPE_STRING, TP_IFACE_CHANNEL_TYPE_TEXT,
+      TP_PROP_CHANNEL_TARGET_HANDLE_TYPE, G_TYPE_UINT, handle_type,
+      TP_PROP_CHANNEL_TARGET_HANDLE, G_TYPE_UINT, handle,
+      TP_PROP_CHANNEL_TARGET_ID, G_TYPE_STRING, target_id,
+      TP_PROP_CHANNEL_REQUESTED, G_TYPE_BOOLEAN, requested,
+      TP_PROP_CHANNEL_INITIATOR_HANDLE, G_TYPE_UINT, initiator_handle,
+      TP_PROP_CHANNEL_INITIATOR_ID, G_TYPE_STRING, initiator_id,
+      TP_PROP_CHANNEL_INTERFACES, G_TYPE_STRV, interfaces,
+      NULL);
+
+  g_free (target_id);
+  g_free (initiator_id);
+  g_strfreev (interfaces);
+  return props;
+}
